@@ -109,6 +109,11 @@ bump_aes_layer <- function(layer, new_aes) {
       old_aes <- names(new_layer$geom$default_aes)[remove_new(names(new_layer$geom$default_aes)) %in% new_aes]
     }
   }
+  # Return unchanged layer if it doens't use this aes
+  if (length(old_aes) == 0) {
+    return(new_layer)
+  }
+
   new_aes <- paste0(old_aes, "_new")
 
   old_geom <- new_layer$geom
@@ -170,6 +175,13 @@ bump_aes_layer <- function(layer, new_aes) {
 
   new_layer$stat <- new_stat
 
+  # Make implicit mapping explicit.
+  # This fixes https://github.com/eliocamp/ggnewscale/issues/45 but it feels
+  # wrong. I don't understand why implicit mapping breaks when adding more than
+  # one extra scale.
+  if (is.null(new_layer$mapping[[old_aes]])) {
+    new_layer$mapping[[old_aes]] <- new_stat$default_aes[[new_aes]]
+  }
   new_layer$mapping <- change_name(new_layer$mapping, old_aes, new_aes)
   new_layer$aes_params <- change_name(new_layer$aes_params, old_aes, new_aes)
   new_layer
@@ -193,6 +205,11 @@ bump_aes_scale <- function(scale, new_aes) {
         scale$guide <- get(paste0("guide_", scale$guide), mode = "function")()
       }
       scale$guide$available_aes[scale$guide$available_aes %in% old_aes] <- new_aes
+
+      if (!is.null(scale$guide$override.aes)) {
+        names(scale$guide$override.aes)[names(scale$guide$override.aes) == old_aes] <- new_aes
+      }
+
     }
   }
 
